//////////////////////////////////////////////////////////////////
// File: Converter.cs
// Class: Converter
// This program converts Fahrenheit <-> Celsius, Kilometer <-> Mile
// using the formula F = (9/5)*C + 32 & C = (F - 32)*(5/9)
// -Kyoung Shin Park (2017 Fall) Updated
//////////////////////////////////////////////////////////////////

using System;

class TemperatureConverter
{
    public enum ConverterType
    {
        FAHRENHEIT_TO_CELSIUS = 1,
        CELSIUS_TO_FAHRENHEIT = 2,
        KILOMETER_TO_MILE = 3,
        MILE_TO_KILOMETER = 4
    }

    public static ConverterType? GetConverterTypeFrom(string name) // if/elseif Ǵ switch 
    {
        switch (name)
        {
            case "F2C":
            case "ȭ2":
                return ConverterType.FAHRENHEIT_TO_CELSIUS;
            case "C2F":
            case "2ȭ":
                return ConverterType.CELSIUS_TO_FAHRENHEIT;
            case "K2M":
            case "ųι2":
                return ConverterType.KILOMETER_TO_MILE;
            case "M2K":
            case "2ųι":
                return ConverterType.MILE_TO_KILOMETER;
            default:
                return null;
        }
    }

    public static float FromFahrenheitToCelsius(float F)
    {
        return (F - 32.0f) * (5.0f / 9.0f);
    }

    public static float FromCelsiusToFahrenheit(float C)
    {
        return ((9.0f / 5.0f) * C + 32.0f);
    }

    public static float FromKilometerToMile(float km)
    {
        return (km * 0.62137f);
    }

    public static float FromMileToKilometer(float mile)
    {
        return (mile / 0.62137f);
    }

    public static void Calculate(ConverterType type)
    {
        Calculate((int)type);
    }

    public static void Calculate(int type)
    {
        switch (type)
        {
            case 1:
                System.Console.Write("Please enter temperature (Fahrenheit): ");
                float tempF = GetUserInputFloat();
                System.Console.WriteLine("F = {0} => C = {1}\n", tempF, FromFahrenheitToCelsius(tempF));
                break;
            case 2:
                System.Console.Write("Please enter temperature (Celsius): ");
                float tempC = GetUserInputFloat();
                System.Console.WriteLine("C = {0} => F = {1}\n", tempC, FromCelsiusToFahrenheit(tempC));
                break;
            case 3:
                System.Console.Write("Please enter length (km): ");
                float tempKilometer = GetUserInputFloat();
                System.Console.WriteLine("Kilometer = {0} => Mile = {1}\n", tempKilometer, FromKilometerToMile(tempKilometer));
                break;
            case 4:
                System.Console.Write("Please enter length (mile): ");
                float tempMile = GetUserInputFloat();
                System.Console.WriteLine("Mile = {0} => Kilometer = {1}\n", tempMile, FromMileToKilometer(tempMile));
                break;
        }
    }

    public static float GetUserInputFloat()
    {
        double value;
        while (!double.TryParse(Console.ReadLine(), out value))
        {
            System.Console.WriteLine("Error! Please re-enter [float value]");
        }
        return (float)value;
    }

    public static int GetUserInput()
    {
        int value = 0;
        do
        {
            System.Console.Write("Enter 1.Fahrenheit->Celsius 2.Celsius->Fahrenheit 3.Kilometer->Mile 4.Mile->Kilometer: ");
            if (!int.TryParse(Console.ReadLine(), out value))
            {
                Console.WriteLine("Error! Please re-enter [int value]");
            }
        } while (value < 1 || value > 4);
        return value;
    }

    public static void Main(string[] args)
    {
        foreach (int i in new int[5] { 2, 1, 3, 4, 2})
        {
            Calculate(i);
        }

        foreach (ConverterType c in ConverterType.GetValues(typeof(ConverterType)))
        {
            Calculate(c);
        }

        int mode = GetUserInput();
        Calculate(mode);

        // Keep the console window open in debug mode.
        Console.WriteLine("Press any key to exit.");
        Console.ReadKey();
    }
}
